FloatingMenuAnchoredOverlayPlacement enum
Values
- auto → const FloatingMenuAnchoredOverlayPlacement
-
Chooses the best placement (top/bottom/start/end) based on available space.
- top → const FloatingMenuAnchoredOverlayPlacement
-
Shows the panel above the anchor.
- bottom → const FloatingMenuAnchoredOverlayPlacement
-
Shows the panel below the anchor.
- start → const FloatingMenuAnchoredOverlayPlacement
-
Shows the panel at the start side (left in LTR, right in RTL).
- end → const FloatingMenuAnchoredOverlayPlacement
-
Shows the panel at the end side (right in LTR, left in RTL).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FloatingMenuAnchoredOverlayPlacement> - A constant List of the values in this enum, in order of their declaration.